@@ -1,20 +1,23 @@
 import json
 
 import grpc
-
 import vegaapiclient as vac
 
 
-def test_grpc_error_detail(tradingdata):
+def test_grpc_error_detail(corenode_trading):
     # Construct a request of the WRONG type.
-    req = vac.api.trading.MarketByIDRequest(market_id="1234")
+    req = vac.vega.api.trading.SubmitTransactionRequest(
+        tx=vac.vega.commands.v1.transaction.Transaction(
+            input_data=bytes("\x00\x01\x02", "ascii"),
+        ),
+    )
     # TODO: use: with pytest.raises(grpc.RpcError) as e_info:
     try:
         # Make a call using the WRONG request type.
-        result = tradingdata.Candles(req)
+        result = corenode_trading.PropagateChainEvent(req)
         print(f"result={result}")
         assert False, (
-            "The gRPC call using the WRONG request message type should have"
+            "The gRPC call using the WRONG request message type should have "
             "failed, but did not."
         )
     except grpc.RpcError as exc:
